@@ -204,7 +204,7 @@ class DsaKey(object):
         except KeyError:
             raise AttributeError(item)
 
-    def exportKey(self, format='PEM', pkcs8=None, passphrase=None,
+    def export_key(self, format='PEM', pkcs8=None, passphrase=None,
                   protection=None, randfunc=None):
         """Export this DSA key.
 
@@ -329,6 +329,9 @@ class DsaKey(object):
             return tobytes(pem_str)
         raise ValueError("Unknown key format '%s'. Cannot export the DSA key." % format)
 
+    # Backward-compatibility
+    exportKey = export_key
+
     # Methods defined in PyCryptodome that we don't support anymore
 
     def sign(self, M, K):
@@ -382,7 +385,7 @@ def _generate_domain(L, randfunc):
               for j in range(n + 1) ]
         V = [ Integer.from_bytes(v) for v in V ]
         W = sum([V[i] * (1 << (i * outlen)) for i in range(n)],
-                (V[n] & (1 << b_ - 1)) * (1 << (n * outlen)))
+                (V[n] & ((1 << b_) - 1)) * (1 << (n * outlen)))
 
         X = Integer(W + upper_bit) # 2^{L-1} < X < 2^{L}
         assert(X.size_in_bits() == L)
